bayespy.inference.vmp.transformations.RotateGaussian.get_bound_terms
====================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateGaussian.get_bound_terms